@@ -1,11 +1,14 @@
+from typing import Union
+
 from pydantic import BaseModel
 
-from spei.types import CodigoErrorAcuse, TipoRespuestaAcuse
+from spei.errors.sice import CodigoErrorAcuseBanxico, CodigoErrorAcuseServidor
+from spei.types.sice import TipoRespuestaAcuse
 from spei.utils import to_snake_case  # noqa: WPS347
 
 
 class Resultado(BaseModel):
-    codigo: CodigoErrorAcuse
+    codigo: Union[CodigoErrorAcuseBanxico, CodigoErrorAcuseServidor]
     descripcion: str
 
     class Config:  # noqa: WPS306, WPS431
